@@ -19,9 +19,9 @@
 
 
 #include "plaintextextractor.h"
-
 #include <QFile>
-#include <QTextStream>
+
+#include <fstream>
 
 using namespace KFileMetaData;
 
@@ -36,34 +36,25 @@ QStringList PlainTextExtractor::mimetypes() const
     return QStringList() << QLatin1String("text/");
 }
 
-// TODO: Make this iterative! And remove the size filter
 void PlainTextExtractor::extract(ExtractionResult* result)
 {
-    QFile file(result->inputUrl());
+    std::string line;
+    int lines = 0;
 
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+    std::ifstream fstream(QFile::encodeName(result->inputUrl()));
+    if (!fstream.is_open()) {
         return;
     }
 
-    int lines = 0;
-    int words = 0;
-
-    QRegExp wordsRegex("\\b\\w+\\b");
-
-    QTextStream ts(&file);
-    while (!ts.atEnd()) {
-        QString str = ts.readLine();
-        result->append(str);
+    while (std::getline(fstream, line)) {
+        QByteArray arr = QByteArray::fromRawData(line.c_str(), line.size());
+        result->append(QString::fromUtf8(arr));
 
         lines += 1;
-        words += str.count(wordsRegex);
     }
 
-    result->add(Property::WordCount, words);
     result->add(Property::LineCount, lines);
     result->addType(Type::Text);
-
-    return;
 }
 
 KFILEMETADATA_EXPORT_EXTRACTOR(KFileMetaData::PlainTextExtractor, "kfilemetadata_plaintextextractor")
